## 1.36.0.2 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 1.36.0.1 (2023-02-07)

Bump mypy to 1.0 (#9684)

## 1.36.0.0 (2023-01-27)

[stubsabot] Bump influxdb-client to 1.36.* (#9594)

Release: https://pypi.org/pypi/influxdb-client/1.36.0
Homepage: https://github.com/influxdata/influxdb-client-python
Diff: https://github.com/influxdata/influxdb-client-python/compare/v1.35.0...v1.36.0

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 4 files included in typeshed's stubs have been modified or renamed: `influxdb_client/client/flux_table.py`, `influxdb_client/client/write/point.py`, `influxdb_client/client/write_api.py`, `influxdb_client/version.py`.
 - Total lines of Python code added: 151.
 - Total lines of Python code deleted: 16.

## 1.35.0.2 (2023-01-14)

Allow influxdb-client to be completely tested by stubtest (#9529)

## 1.35.0.1 (2023-01-02)

[influxdb-client] Annotate Point and partially client classes (#9442)

## 1.35.0.0 (2022-12-31)

Add stubs for influxdb-client (#9429)

